@@ -1,4 +1,3 @@
-
 class NotLoggedInException(Exception):
     pass
 
@@ -29,3 +28,15 @@ class FailedToUploadFileException(Exception):
 
 class FailedToParseGradeDataError(Exception):
     pass
+
+
+class ExpiredSessionException(Exception):
+    pass
+
+
+class InvalidTeacherException(Exception):
+    pass
+
+
+class RequestError(Exception):
+    pass
