@@ -1,4 +1,5 @@
 import json
+from dataclasses import dataclass
 from datetime import datetime
 from typing import List, Optional
 
@@ -8,18 +9,16 @@ from edupage_api.exceptions import (FailedToChangeLunchError,
 from edupage_api.module import EdupageModule, Module, ModuleHelper
 
 
+@dataclass
 class Rating:
-    def __init__(self, mysql_date, boarder_id,
-                 quality_average, quantity_average,
-                 quality_ratings, quantity_ratings):
-        self.quality_ratings = quality_ratings
-        self.quality_average = quality_average
+    __date: str
+    __boarder_id: str
 
-        self.quantity_ratings = quantity_ratings
-        self.quantity_average = quantity_average
+    quality_average: float
+    quality_average: float
 
-        self.__date = mysql_date
-        self.__boarder_id = boarder_id
+    quantity_average: float
+    quantity_ratings: float
 
     def rate(self, edupage: EdupageModule, quantity: int, quality: int):
         if not edupage.is_logged_in:
@@ -44,30 +43,25 @@ class Rating:
             raise FailedToRateException()
 
 
+@dataclass
 class Menu:
-    def __init__(self, name: str, allergens: str, weight: str, number: str, rating: Optional[Rating]):
-        self.name = name
-        self.allergens = allergens
-        self.weight = weight
-        self.number = number
-        self.rating = rating
+    name: str
+    allergens: str
+    weight: str
+    number: str
+    rating: Optional[Rating]
 
 
 class Lunch:
-    def __init__(self, served_from: Optional[datetime], served_to: Optional[datetime],
-                 amount_of_foods: int, chooseable_menus: list[str],
-                 can_be_changed_until: datetime, title: str,
-                 menus: List[Menu], date: datetime,
-                 boarder_id: str):
-        self.date = date
-        self.served_from = served_from
-        self.served_to = served_to
-        self.amount_of_foods = amount_of_foods
-        self.chooseable_menus = chooseable_menus
-        self.can_be_changed_until = can_be_changed_until
-        self.title = title
-        self.menus = menus
-        self.__boarder_id = boarder_id
+    served_from: Optional[datetime]
+    served_to: Optional[datetime]
+    amount_of_foods: int
+    chooseable_menus: list[str]
+    can_be_changed_until: datetime
+    title: str
+    menus: List[Menu]
+    date: datetime
+    __boarder_id: str
 
     def __iter__(self):
         return iter(self.menus)
@@ -108,7 +102,8 @@ class Lunch:
 class Lunches(Module):
     @ModuleHelper.logged_in
     def get_lunch(self, date: datetime):
-        request_url = f"https://{self.edupage.subdomain}.edupage.org/menu/"
+        date_strftime = date.strftime("%Y%m%d")
+        request_url = f"https://{self.edupage.subdomain}.edupage.org/menu/?date={date_strftime}"
         response = self.edupage.session.get(request_url).content.decode()
 
         boarder_id = response.split("var stravnikid = \"")[1].split("\"")[0]
