@@ -1,6 +1,7 @@
 import json
+from dataclasses import dataclass
 from datetime import datetime
-from typing import List, Optional, Union
+from typing import List, Optional
 
 from edupage_api.dbi import DbiHelper
 from edupage_api.exceptions import MissingDataException
@@ -8,17 +9,15 @@ from edupage_api.module import EdupageModule, Module, ModuleHelper
 from edupage_api.people import EduTeacher, People
 
 
+@dataclass
 class Lesson:
-    def __init__(self, teachers: List[EduTeacher], classrooms: List[str],
-                 start_of_lesson: datetime, end_of_lesson: datetime,
-                 online_lesson_link: Optional[str], subject_id: int, name: str):
-        self.teachers = teachers
-        self.classrooms = classrooms
-        self.start_of_lesson = start_of_lesson
-        self.end_of_lesson = end_of_lesson
-        self.online_lesson_link = online_lesson_link
-        self.subject_id = subject_id
-        self.name = name
+    teachers: List[EduTeacher]
+    classrooms: List[str]
+    start_of_lesson: datetime
+    end_of_lesson: datetime
+    online_lesson_link: Optional[str]
+    subject_id: int
+    name: str
 
     def is_online_lesson(self) -> bool:
         return self.online_lesson_link is None
@@ -38,12 +37,12 @@ class Lesson:
         post_data = {
             "__args": [
                 None,
-                {
-                    "click": True,
-                    "date": today.strftime("%Y-%m-%d"),
-                    "ol_url": self.online_lesson_link,
-                    "subjectid": self.subject_id
-                }
+                    {
+                        "click": True,
+                        "date": today.strftime("%Y-%m-%d"),
+                        "ol_url": self.online_lesson_link,
+                        "subjectid": self.subject_id
+                    }
             ],
             "__gsh": gse_hash
         }
@@ -52,9 +51,9 @@ class Lesson:
         return json.loads(response.content.decode()).get("reload") is not None
 
 
+@dataclass
 class Timetable:
-    def __init__(self, lessons: List[Lesson]):
-        self.lessons = lessons
+    lessons: List[Lesson]
 
     def __iter__(self):
         return iter(self.lessons)
@@ -99,7 +98,7 @@ class Timetables(Module):
 
         return dp
 
-    def get_timetable(self, date: datetime) -> Union[Timetable, None]:
+    def get_timetable(self, date: datetime) -> Optional[Timetable]:
         dp = self.__get_dp()
 
         dates = dp.get("dates")
